@@ -1,5 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nill; c-basic-offset: 8 -*- */
 /*
+ * Copyright (C) 2004-2005 Imendio AB
  * Copyright (C) 2002-2003 CodeFactory AB
  * Copyright (C) 2002-2003 Richard Hult <richard@imendio.com>
  * Copyright (C) 2002 Mikael Hallendal <micke@imendio.com>
@@ -28,7 +29,7 @@
 #include <stdlib.h>
 #include "mrp-private.h"
 #include "mrp-error.h"
-#include "mrp-intl.h"
+#include <glib/gi18n.h>
 #include "mrp-task.h"
 #include "mrp-resource.h"
 #include "mrp-group.h"
@@ -231,7 +232,7 @@ old_xml_read_task (MrpParser *parser, xmlNodePtr tree, MrpTask *parent)
 	priority = old_xml_get_int (tree, "priority");
 	type = old_xml_get_task_type (tree, "type");
 	sched = old_xml_get_task_sched (tree, "scheduling");
-	
+
 	if (parser->version == 1) {
 		start = old_xml_get_date (tree, "start");
 		end = old_xml_get_date (tree, "end");
@@ -325,6 +326,14 @@ old_xml_read_task (MrpParser *parser, xmlNodePtr tree, MrpTask *parent)
 	
 	for (tasks = tree->children; tasks; tasks = tasks->next) {
 		if (!strcmp (tasks->name, "task")) {
+			/* Silently correct old milestones with children to
+			 * normal tasks.
+			 */
+			if (type == MRP_TASK_TYPE_MILESTONE) {
+				type = MRP_TASK_TYPE_NORMAL;
+				g_object_set (task, "type", type, NULL);
+			}
+			
 			old_xml_read_task (parser, tasks, task);
 		}
 		else if (!strcmp (tasks->name, "predecessors")) {
@@ -646,7 +655,7 @@ old_xml_read_overridden_day (MrpParser   *parser,
 	
 	if (sscanf (xml_str, "%04d%02d%02d", &y, &m, &d) == 3) {
 		date = mrp_time_compose (y, m, d, 0, 0, 0);
-		mrp_calendar_set_days (calendar, date, mrp_day, -1);		
+		mrp_calendar_set_days (calendar, date, mrp_day, (mrptime) -1);		
 	} else {
 		g_warning ("Invalid time format for overridden day.");
 	}
@@ -869,13 +878,24 @@ old_xml_read_property_specs (MrpParser *parser)
 
 		type = old_xml_property_type_from_string (type_str);
 		
-		/* #534 */
 		property = mrp_property_new (name,
 					     type,
 					     label,
 					     description,
 					     TRUE);
 
+		/* If we could't create the property, this means that we are
+		 * trying to use a name that is already taken.
+		 */
+		if (!property) {
+			g_free (name);
+			g_free (type_str);
+			g_free (owner_str);
+			g_free (label);
+			g_free (description);
+			continue;
+		}
+		
 		if (!strcmp (owner_str, "task")) {
 			owner = MRP_TYPE_TASK;
 		}
@@ -1038,12 +1058,13 @@ old_xml_read_project (MrpParser *parser)
 		for (groups = child->children; groups; groups = groups->next) {
 			old_xml_read_group (parser, groups); 
 		}
+
+		/* Gah, why underscore?! */
+		gid = old_xml_get_int (child, "default_group");
+		parser->default_group = g_hash_table_lookup (parser->group_hash,
+							     GINT_TO_POINTER (gid));
 	}
 	
-	gid = old_xml_get_int (child, "default_group");
-        parser->default_group = g_hash_table_lookup (parser->group_hash,
-						     GINT_TO_POINTER (gid));
-
 	/* Load resources. */
  	child = old_xml_search_child (parser->doc->children, "resources"); 
 	if (child != NULL) {
@@ -1353,14 +1374,21 @@ old_xml_set_property_from_node (MrpProject *project,
 
 	str = old_xml_get_string (node, "value");
 
+	/* Check if we have the property first. This is needed both to be robust
+	 * against broken input.
+	 */
+	if (!mrp_project_has_property (project,
+				       G_OBJECT_TYPE (object),
+				       name)) {
+		g_free (name);
+		g_free (str);
+		return;
+	}
+	
 	property = mrp_project_get_property (project,
 					     name,
 					     G_OBJECT_TYPE (object));
 
-	if (property == NULL) {
-		return;
-	}
-	
 	type = mrp_property_get_property_type (property);
 
 	switch (type) {
