@@ -1,8 +1,10 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
+ * Copyright (C) 2004 Imendio AB
  * Copyright (C) 2002-2003 CodeFactory AB
  * Copyright (C) 2002-2003 Richard Hult <richard@imendio.com>
  * Copyright (C) 2002 Mikael Hallendal <micke@imendio.com>
+ * Copyright (C) 2004 Alvaro del Castillo <acs@barrapunto.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,7 +26,7 @@
 #include <string.h>
 #include "mrp-private.h"
 #include "mrp-marshal.h"
-#include "mrp-intl.h"
+#include <glib/gi18n.h>
 #include "mrp-assignment.h"
 #include "mrp-group.h"
 #include "mrp-task.h"
@@ -33,6 +35,7 @@
 
 struct _MrpResourcePriv {
 	gchar           *name;
+	gchar		*short_name;
         MrpGroup        *group;
         MrpResourceType  type;
         gint             units;
@@ -41,18 +44,21 @@ struct _MrpResourcePriv {
 	GList           *assignments;
 	
 	MrpCalendar     *calendar;
+	gfloat           cost;
 };
 
 /* Properties */
 enum {
         PROP_0,
         PROP_NAME,
+	PROP_SHORT_NAME,
         PROP_GROUP,
         PROP_TYPE,
         PROP_UNITS,
         PROP_EMAIL,
         PROP_NOTE,
-	PROP_CALENDAR
+	PROP_CALENDAR,
+	PROP_COST
 };
 
 /* Signals */
@@ -63,21 +69,25 @@ enum {
 };
 
 
-static void resource_class_init            (MrpResourceClass   *klass);
-static void resource_init                  (MrpResource        *resource);
-static void resource_finalize              (GObject            *object);
-static void resource_set_property          (GObject            *object,
-					    guint               prop_id,
-					    const GValue       *value,
-					    GParamSpec         *pspec);
-static void resource_get_property          (GObject            *object,
-					    guint               prop_id,
-					    GValue             *value,
-					    GParamSpec         *pspec);
-static void resource_removed               (MrpObject          *object);
-static void resource_assignment_removed_cb (MrpAssignment      *assignment,
-					    MrpResource        *resource);
-
+static void resource_class_init            (MrpResourceClass *klass);
+static void resource_init                  (MrpResource      *resource);
+static void resource_finalize              (GObject          *object);
+static void resource_set_property          (GObject          *object,
+					    guint             prop_id,
+					    const GValue     *value,
+					    GParamSpec       *pspec);
+static void resource_get_property          (GObject          *object,
+					    guint             prop_id,
+					    GValue           *value,
+					    GParamSpec       *pspec);
+static void resource_calendar_changed      (MrpCalendar      *calendar,
+					    MrpResource      *resource);
+static void resource_removed               (MrpObject        *object);
+static void resource_invalidate_task_costs (MrpResource      *resource);
+static void resource_assignment_removed_cb (MrpAssignment    *assignment,
+					    MrpResource      *resource);
+static void resource_group_removed_cb      (MrpGroup         *group,
+					    MrpResource      *resource);
 
 
 static MrpObjectClass *parent_class;
@@ -132,6 +142,13 @@ resource_class_init (MrpResourceClass *klass)
                                                               "The name of the resource",
                                                               NULL,
                                                               G_PARAM_READWRITE));
+        g_object_class_install_property (object_class,
+                                         PROP_SHORT_NAME,
+                                         g_param_spec_string ("short_name",
+                                                              "Short name",
+                                                              "The shorter name, initials or nickname of the resource",
+                                                              NULL,
+                                                              G_PARAM_READWRITE));
         g_object_class_install_property (object_class,
                                          PROP_GROUP,
                                          g_param_spec_object ("group",
@@ -179,6 +196,15 @@ resource_class_init (MrpResourceClass *klass)
 							       "Calendar",
 							       "The calendar this resource uses",
 							       G_PARAM_READWRITE));
+        g_object_class_install_property (object_class,
+                                         PROP_COST,
+                                         g_param_spec_float ("cost",
+                                                             "Cost",
+                                                             "The standard cost of the resource",
+                                                             0.0,
+							     G_MAXFLOAT,
+                                                             0.0,
+                                                             G_PARAM_READWRITE));
                 
 	/* Signals */
 	signals[ASSIGNMENT_ADDED] = 
@@ -212,6 +238,7 @@ resource_init (MrpResource *resource)
 	priv->assignments = NULL;
 	priv->type        = MRP_RESOURCE_TYPE_NONE;
         priv->name        = g_strdup ("");
+	priv->short_name    = g_strdup ("");
 	priv->group       = NULL;
 	priv->email       = g_strdup ("");
 	priv->note        = g_strdup ("");   
@@ -227,6 +254,7 @@ resource_finalize (GObject *object)
         priv = resource->priv;
 
         g_free (priv->name);
+	g_free (priv->short_name);
         g_free (priv->email);
         g_free (priv->note);
 	if (priv->group) {
@@ -236,16 +264,6 @@ resource_finalize (GObject *object)
 		g_object_unref (priv->calendar);
 	}
 	
-	if (priv->assignments) {
-		GList *l;
-		
-		for (l = priv->assignments; l; l = l->next) {
-			g_object_unref (l->data);
-		}
-		
-		g_list_free (priv->assignments);
-	}
-	
 	g_free (priv);
 	resource->priv = NULL;
 
@@ -265,8 +283,10 @@ resource_set_property (GObject      *object,
 	gboolean         changed = FALSE;
 	const gchar     *str;
 	gint             i_val;
+	gfloat           f_val;
 	MrpGroup        *group;
 	MrpCalendar     *calendar;
+	MrpProject      *project;
 	
 	resource = MRP_RESOURCE (object);
 	priv     = resource->priv;
@@ -280,14 +300,33 @@ resource_set_property (GObject      *object,
 			changed = TRUE;
 		}
 		break;
+		
+	case PROP_SHORT_NAME: 
+		str = g_value_get_string (value);
+		if (!priv->short_name || strcmp (priv->short_name, str)) {
+			g_free (priv->short_name);
+			priv->short_name = g_strdup (str);
+			changed = TRUE;
+		}
+		break;
+
 	case PROP_GROUP:
 		if (priv->group != NULL) {
 			g_object_unref (priv->group);
+			g_signal_handlers_disconnect_by_func 
+				(priv->group,
+				 resource_group_removed_cb,
+				 resource);
+			
 		}
 
 		group = g_value_get_object (value);
 		if (group != NULL) {
 			g_object_ref (group);
+			g_signal_connect (G_OBJECT (group),
+					  "removed",
+					  G_CALLBACK (resource_group_removed_cb),
+					  resource);
 		}
 		if (group != priv->group) {
 			changed = TRUE;
@@ -336,16 +375,42 @@ resource_set_property (GObject      *object,
 		} else {
 			break;
 		}
-
+		
 		if (priv->calendar != NULL) {
+			g_signal_handlers_disconnect_by_func (priv->calendar,
+							      resource_calendar_changed,
+							      resource);
 			g_object_unref (priv->calendar);
 		}
 		
 		if (calendar != NULL) {
 			g_object_ref (calendar);
+			
+			g_signal_connect_object (calendar,
+						 "calendar_changed",
+						 G_CALLBACK (resource_calendar_changed),
+						 resource,
+						 0);
 		}
 
 		priv->calendar = calendar;
+
+		/* Make sure the project is rescheduled if necessary. */
+		if (priv->assignments) {
+			project = mrp_object_get_project (MRP_OBJECT (resource));
+			if (project) {
+				mrp_project_reschedule (project);
+			}
+		}
+		break;
+	case PROP_COST:
+		f_val = g_value_get_float (value);
+		
+		if (priv->cost != f_val) {
+			priv->cost = f_val;
+			changed = TRUE;
+			resource_invalidate_task_costs (resource);
+		}
 		break;
 
 	default:
@@ -373,6 +438,9 @@ resource_get_property (GObject    *object,
 	case PROP_NAME:
 		g_value_set_string (value, priv->name);
 		break;
+	case PROP_SHORT_NAME:
+		g_value_set_string (value, priv->short_name);
+		break;
 	case PROP_GROUP:
 		g_value_set_object (value, priv->group);
 		break;
@@ -391,12 +459,30 @@ resource_get_property (GObject    *object,
 	case PROP_CALENDAR:
 		g_value_set_pointer (value, priv->calendar);
 		break;
+	case PROP_COST:
+		g_value_set_float (value, priv->cost);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
 	}
 }
 
+static void
+resource_calendar_changed (MrpCalendar *calendar,
+			   MrpResource *resource)
+{
+	MrpProject *project;
+
+	project = mrp_object_get_project (MRP_OBJECT (resource));
+
+	if (!project) {
+		return;
+	}
+			
+	mrp_project_reschedule (project);
+}
+
 static void
 resource_remove_assignment_foreach (MrpAssignment *assignment, 
 				    MrpResource   *resource)
@@ -406,9 +492,21 @@ resource_remove_assignment_foreach (MrpAssignment *assignment,
 	g_signal_handlers_disconnect_by_func (MRP_OBJECT (assignment),
 					      resource_assignment_removed_cb,
 					      resource);
+
+	g_object_unref (assignment);
+
 	mrp_object_removed (MRP_OBJECT (assignment));
 }
 
+static void
+resource_invalidate_task_cost_foreach (MrpAssignment *assignment, 
+				       MrpResource   *resource)
+{
+	g_return_if_fail (MRP_IS_ASSIGNMENT (assignment));
+
+	mrp_task_invalidate_cost (mrp_assignment_get_task (assignment));
+}
+
 static void
 resource_removed (MrpObject *object)
 {
@@ -424,13 +522,27 @@ resource_removed (MrpObject *object)
 			(GFunc) resource_remove_assignment_foreach,
 			resource);
 	
+	g_list_free (priv->assignments);
+	priv->assignments = NULL;
+
         if (MRP_OBJECT_CLASS (parent_class)->removed) {
                 (* MRP_OBJECT_CLASS (parent_class)->removed) (object);
         }
 }
 
 static void
-resource_assignment_removed_cb (MrpAssignment *assignment, MrpResource *resource)
+resource_group_removed_cb (MrpGroup     *group,
+			   MrpResource  *resource)
+{
+	g_return_if_fail (MRP_IS_RESOURCE (resource));
+	g_return_if_fail (MRP_IS_GROUP (group));
+
+	mrp_object_set (MRP_OBJECT (resource), "group", NULL, NULL);
+}
+
+static void
+resource_assignment_removed_cb (MrpAssignment *assignment, 
+				MrpResource *resource)
 {
 	MrpResourcePriv *priv;
 	MrpTask         *task;
@@ -458,6 +570,14 @@ resource_assignment_removed_cb (MrpAssignment *assignment, MrpResource *resource
 	mrp_object_changed (MRP_OBJECT (resource));
 }
 
+static void
+resource_invalidate_task_costs (MrpResource *resource)
+{
+	g_list_foreach (resource->priv->assignments,
+			(GFunc) resource_invalidate_task_cost_foreach,
+			resource);
+}
+
 /**
  * mrp_resource_add_assignment:
  * @resource: an #MrpResource
@@ -540,6 +660,36 @@ void mrp_resource_set_name (MrpResource *resource, const gchar *name)
 	mrp_object_set (MRP_OBJECT (resource), "name", name, NULL);
 }
 
+/**
+ * mrp_resource_get_short_name:
+ * @resource: an #MrpResource
+ * 
+ * Retrives the short_name of @resource.
+ * 
+ * Return value: the short name
+ **/
+const gchar *
+mrp_resource_get_short_name (MrpResource *resource)
+{
+	g_return_val_if_fail (MRP_IS_RESOURCE (resource), NULL);
+		
+	return resource->priv->short_name;
+}
+
+/**
+ * mrp_resource_set_short_name:
+ * @resource: an #MrpResource
+ * @name: new short name of @resource
+ * 
+ * Sets the short name of @resource.
+ **/
+void mrp_resource_set_short_name (MrpResource *resource, const gchar *name)
+{
+	g_return_if_fail (MRP_IS_RESOURCE (resource));
+
+	mrp_object_set (MRP_OBJECT (resource), "short_name", name, NULL);
+}
+
 /**
  * mrp_resource_assign:
  * @resource: an #MrpResource
