@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2004 Imendio HB
+ * Copyright (C) 2004-2005 Imendio AB
  * Copyright (C) 2001-2003 CodeFactory AB
  * Copyright (C) 2001-2003 Richard Hult <richard@imendio.com>
  * Copyright (C) 2001-2003 Mikael Hallendal <micke@imendio.com>
@@ -28,7 +28,7 @@
 #include <libplanner/mrp-project.h>
 #include <libplanner/mrp-resource.h>
 #include <libplanner/mrp-task.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnomecanvas/gnome-canvas.h>
 #include "planner-marshal.h"
 #include "planner-format.h"
@@ -207,6 +207,13 @@ static gboolean gantt_row_get_resource_by_index       (PlannerGanttRow       *ro
 						       gint                  *x1,
 						       gint                  *x2);
 
+static PlannerCmd *task_cmd_edit_property (PlannerWindow   *window,
+					   PlannerTaskTree *tree,
+					   MrpTask         *task,
+					   const gchar     *property,
+					   const GValue    *value);
+
+static GList *  gantt_row_get_selected_tasks (GtkTreeSelection *selection);
 
 
 static GnomeCanvasItemClass *parent_class;
@@ -1509,6 +1516,7 @@ gantt_row_event (GnomeCanvasItem *item, GdkEvent *event)
 				GtkTreeSelection  *selection;
 				GtkTreeView       *tree_view;
 				GtkTreeIter        iter;
+				GList             *tasks;
 				
 				chart = g_object_get_data (G_OBJECT (item->canvas), "chart");
 				tree = planner_gantt_chart_get_view (chart);
@@ -1529,6 +1537,10 @@ gantt_row_event (GnomeCanvasItem *item, GdkEvent *event)
 					gtk_tree_selection_select_path (selection, path);
 					planner_task_tree_set_anchor (tree, path);
 				}
+
+				tasks = gantt_row_get_selected_tasks (selection);
+				planner_task_popup_update_sensitivity (priv->popup_factory, tasks);
+				g_list_free (tasks);
 				
 				gtk_item_factory_popup (priv->popup_factory,
 							event->button.x_root,
@@ -1605,9 +1617,7 @@ gantt_row_event (GnomeCanvasItem *item, GdkEvent *event)
 
 				old_target_item = NULL;
 
-				/*
-				 * Start the autoscroll timeout.
-				 */
+				/* Start the autoscroll timeout. */
 				priv->scroll_timeout_id = gtk_timeout_add (
 					50,
 					(GSourceFunc) gantt_row_scroll_timeout_cb,
@@ -1751,7 +1761,6 @@ gantt_row_event (GnomeCanvasItem *item, GdkEvent *event)
 					      NULL);
 
 				target_name = mrp_task_get_name (PLANNER_GANTT_ROW (target_item)->priv->task);
-
 				task_name = mrp_task_get_name (priv->task);
 				
 				if (target_name == NULL || target_name[0] == 0) {
@@ -1780,14 +1789,8 @@ gantt_row_event (GnomeCanvasItem *item, GdkEvent *event)
 			gint         duration;
 			gint         work;
 			MrpProject  *project;
-			MrpCalendar *calendar;
-			gint         hours_per_day;
 
 			project = mrp_object_get_project (MRP_OBJECT (priv->task));
-			calendar = mrp_project_get_calendar (project);
-			
-			hours_per_day = mrp_calendar_day_get_total_work (
-				calendar, mrp_day_get_work ()) / (60*60);
 
 			wx2 = event->motion.x;
 			wy2 = priv->y + 0.70 * priv->height;
@@ -1802,8 +1805,7 @@ gantt_row_event (GnomeCanvasItem *item, GdkEvent *event)
 			gnome_canvas_item_raise_to_top (drag_item);
 			gnome_canvas_item_show (drag_item);
 
-			chart = g_object_get_data (G_OBJECT (item->canvas),
-						   "chart");
+			chart = g_object_get_data (G_OBJECT (item->canvas), "chart");
 
 			duration = MAX (0, (event->motion.x - priv->x_start) / priv->scale);
 
@@ -1816,16 +1818,19 @@ gantt_row_event (GnomeCanvasItem *item, GdkEvent *event)
 				-1,
 				mrp_task_get_start (priv->task) + duration);
 
-			message = g_strdup_printf (
-				_("Change work to %s"),
-				planner_format_duration (work, hours_per_day));
+			message = g_strdup_printf (_("Change work to %s"),
+						   planner_format_duration (project, work));
 			planner_gantt_chart_status_updated (chart, message);
 			g_free (message);
 		}
 			
 		break;
 		
-	case GDK_BUTTON_RELEASE:
+	case GDK_BUTTON_RELEASE: {
+		PlannerTaskTree  *tree;
+		GtkTreePath      *path;
+		GtkTreeSelection *selection;
+				
 		if (event->button.button != 1) {
 			return FALSE;
 		}
@@ -1837,10 +1842,12 @@ gantt_row_event (GnomeCanvasItem *item, GdkEvent *event)
 			MrpProject *project;
 			gint        duration;
 			gint        work;
+			GValue      value = { 0 };
 
 			project = mrp_object_get_project (MRP_OBJECT (priv->task));
 			
 			duration = MAX (0, (event->button.x - priv->x_start) / priv->scale);
+
 			/* Snap to quarters. */
 			duration = floor (duration / SNAP + 0.5) * SNAP;
 
@@ -1849,17 +1856,26 @@ gantt_row_event (GnomeCanvasItem *item, GdkEvent *event)
 				priv->task,
 				-1,
 				mrp_task_get_start (priv->task) + duration);
+
+			chart = g_object_get_data (G_OBJECT (item->canvas), "chart");
+			tree = planner_gantt_chart_get_view (chart);
+
+			g_value_init (&value, G_TYPE_INT);
+			g_value_set_int (&value, work);
 			
-			g_object_set (priv->task,
+			task_cmd_edit_property (planner_task_tree_get_window (tree),
+						tree,
+						priv->task,
+						"work",
+						&value);
+
+			/*g_object_set (priv->task,
 				      "work", work,
 				      NULL);
-
+			*/
 			gtk_object_destroy (GTK_OBJECT (drag_item));
 			drag_item = NULL;
 
-			chart = g_object_get_data (G_OBJECT (item->canvas),
-						   "chart");
-
 			planner_gantt_chart_status_updated (chart, NULL);
 		}
 		else if (priv->state == STATE_DRAG_LINK) {
@@ -1905,7 +1921,7 @@ gantt_row_event (GnomeCanvasItem *item, GdkEvent *event)
 							     &error);
 				
 				if (!cmd) {
-					GtkWidget   *dialog;
+					GtkWidget *dialog;
 
 					gnome_canvas_item_ungrab (item, event->button.time);
 					
@@ -1931,10 +1947,6 @@ gantt_row_event (GnomeCanvasItem *item, GdkEvent *event)
 		gnome_canvas_item_ungrab (item, event->button.time);
 		
 		/* Select the clicked on task in the treeview */
-		PlannerTaskTree   *tree;
-		GtkTreePath       *path;
-		GtkTreeSelection  *selection;
-		
 		chart = g_object_get_data (G_OBJECT (item->canvas), "chart");
 		tree = planner_gantt_chart_get_view (chart);
 		gtk_widget_grab_focus (GTK_WIDGET (tree));
@@ -1960,7 +1972,10 @@ gantt_row_event (GnomeCanvasItem *item, GdkEvent *event)
 			planner_task_tree_set_anchor (tree, path);
 		}
 		else if (event->button.state & GDK_SHIFT_MASK) {
-			GtkTreePath* anchor = planner_task_tree_get_anchor (tree);
+			GtkTreePath *anchor;
+
+			anchor = planner_task_tree_get_anchor (tree);
+			
 			if (anchor) {
 				gtk_tree_selection_unselect_all (selection);
 				gtk_tree_selection_select_range(selection, anchor, path);
@@ -1976,15 +1991,15 @@ gantt_row_event (GnomeCanvasItem *item, GdkEvent *event)
 		priv->state = STATE_NONE;
 	
 		return TRUE;
+	}
 		
 	case GDK_2BUTTON_PRESS:
 		if (event->button.button == 1) {
 			if (IN_DRAG_RELATION_SPOT (event->button.x, event->button.y,
 						   priv->x + priv->width, priv->y, priv->height)) {
-	
-				PlannerTaskTree   *tree;
-				GtkTreePath       *path;
-				GtkTreeSelection  *selection;
+				PlannerTaskTree  *tree;
+				GtkTreePath      *path;
+				GtkTreeSelection *selection;
 				
 				chart = g_object_get_data (G_OBJECT (item->canvas), "chart");
 				tree = planner_gantt_chart_get_view (chart);
@@ -2036,14 +2051,14 @@ gantt_row_canvas_scroll (GtkWidget *widget,
 			 gint       delta_y)
 {
 	GtkAdjustment *hadj, *vadj;
-	int old_h_value, old_v_value;
+	int            old_h_value, old_v_value;
 
 	hadj = gtk_layout_get_hadjustment (GTK_LAYOUT (widget));
 	vadj = gtk_layout_get_vadjustment (GTK_LAYOUT (widget));
 
-	/* Store the old ajustment values so we can tell if we ended up actually
-	 * scrolling. We may not have in a case where the resulting value got
-	 * pinned to the adjustment min or max.
+	/* Store the old adjustment values so we can tell if we ended up
+	 * actually scrolling. We may not have in a case where the resulting
+	 * value got pinned to the adjustment min or max.
 	 */
 	old_h_value = hadj->value;
 	old_v_value = vadj->value;
@@ -2057,7 +2072,7 @@ gantt_row_canvas_scroll (GtkWidget *widget,
 
 static gint
 gantt_row_get_resource_index_at (PlannerGanttRow *row,
-				 gint        x)
+				 gint             x)
 {
 	PlannerGanttRowPriv *priv;
 	gint                 i, len;
@@ -2084,9 +2099,9 @@ gantt_row_get_resource_index_at (PlannerGanttRow *row,
 
 static gboolean
 gantt_row_get_resource_by_index (PlannerGanttRow *row,
-				 gint        index,
-				 gint       *x1,
-				 gint       *x2)
+				 gint             index,
+				 gint            *x1,
+				 gint            *x2)
 {
 	PlannerGanttRowPriv *priv;
 
@@ -2126,7 +2141,7 @@ planner_gantt_row_init_menu (PlannerGanttRow *row)
 	row->priv->popup_factory = planner_task_popup_new (tree);
 }
 
-
+/* Save this code for later. */
 #if 0
 	gdouble              wx1, wx2;
 	mrptime              t1, t2;    /* First and last exposed times */
@@ -2286,3 +2301,154 @@ planner_gantt_row_init_menu (PlannerGanttRow *row)
 		}
 
 #endif
+
+
+/* This should be ina shared file ideally, but there are some linking
+ * problems.
+ */
+
+typedef struct {
+	PlannerCmd         base;
+
+	PlannerTaskTree   *tree;
+	MrpProject        *project;
+	
+	GtkTreePath       *path;
+	
+	gchar             *property;  
+	GValue            *value;
+	GValue            *old_value;
+} TaskCmdEditProperty;
+
+static gboolean
+task_cmd_edit_property_do (PlannerCmd *cmd_base)
+{
+	TaskCmdEditProperty *cmd;
+	PlannerGanttModel   *model;
+	MrpTask             *task;
+	
+	cmd = (TaskCmdEditProperty*) cmd_base;
+
+	model = PLANNER_GANTT_MODEL (gtk_tree_view_get_model (GTK_TREE_VIEW (cmd->tree)));
+	task = planner_gantt_model_get_task_from_path (model, cmd->path);
+
+	g_object_set_property (G_OBJECT (task),
+			       cmd->property,
+			       cmd->value);
+
+	return TRUE;
+}
+
+static void
+task_cmd_edit_property_undo (PlannerCmd *cmd_base)
+{
+	TaskCmdEditProperty *cmd;
+	PlannerGanttModel   *model;
+	MrpTask             *task;
+	
+	cmd = (TaskCmdEditProperty*) cmd_base;
+
+	model = PLANNER_GANTT_MODEL (gtk_tree_view_get_model (GTK_TREE_VIEW (cmd->tree)));
+	task = planner_gantt_model_get_task_from_path (model, cmd->path);
+
+	g_object_set_property (G_OBJECT (task),
+			       cmd->property,
+			       cmd->old_value);
+}
+
+static void
+task_cmd_edit_property_free (PlannerCmd *cmd_base)
+{
+	TaskCmdEditProperty *cmd;
+	
+	cmd = (TaskCmdEditProperty*) cmd_base;
+
+	g_object_unref (cmd->project);
+	
+	g_free (cmd->property);
+	g_value_unset (cmd->value);
+	g_value_unset (cmd->old_value);
+
+	g_free (cmd->value);
+	g_free (cmd->old_value);
+}
+
+static PlannerCmd *
+task_cmd_edit_property (PlannerWindow   *window,
+			PlannerTaskTree *tree,
+			MrpTask         *task,
+			const gchar     *property,
+			const GValue    *value)
+{
+	PlannerTaskTreePriv *priv;
+	PlannerCmd          *cmd_base;
+	TaskCmdEditProperty *cmd;
+	PlannerGanttModel   *model;
+
+	priv = tree->priv;
+
+	cmd_base = planner_cmd_new (TaskCmdEditProperty,
+				    _("Edit task property"),
+				    task_cmd_edit_property_do,
+				    task_cmd_edit_property_undo,
+				    task_cmd_edit_property_free);
+
+	cmd = (TaskCmdEditProperty *) cmd_base;
+
+	cmd->tree = tree;
+	cmd->project = g_object_ref (planner_window_get_project (window));
+
+	model = PLANNER_GANTT_MODEL (gtk_tree_view_get_model (GTK_TREE_VIEW (tree)));
+	
+	cmd->path = planner_gantt_model_get_path_from_task (model, task);
+	
+	cmd->property = g_strdup (property);
+
+	cmd->value = g_new0 (GValue, 1);
+	g_value_init (cmd->value, G_VALUE_TYPE (value));
+	g_value_copy (value, cmd->value);
+
+	cmd->old_value = g_new0 (GValue, 1);
+	g_value_init (cmd->old_value, G_VALUE_TYPE (value));
+
+	g_object_get_property (G_OBJECT (task),
+			       cmd->property,
+			       cmd->old_value);
+
+	planner_cmd_manager_insert_and_do (planner_window_get_cmd_manager (window),
+					   cmd_base);
+	
+	return cmd_base;
+}
+
+static  void
+gantt_row_get_selected_func (GtkTreeModel *model,
+			     GtkTreePath  *path,
+			     GtkTreeIter  *iter,
+			     gpointer      data)
+{
+	GList   **list = data;
+	MrpTask  *task;
+
+	gtk_tree_model_get (model,
+			    iter,
+			    COL_TASK, &task,
+			    -1);
+	
+	*list = g_list_prepend (*list, task);
+}
+
+static GList *
+gantt_row_get_selected_tasks (GtkTreeSelection *selection)
+{
+	GList *list;
+	
+	list = NULL;
+	gtk_tree_selection_selected_foreach (selection,
+					     gantt_row_get_selected_func,
+					     &list);
+	
+	list = g_list_reverse (list);
+	
+	return list;
+}
