@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2003 Imendio HB
+ * Copyright (C) 2003 Imendio AB
  * Copyright (C) 2002 CodeFactory AB
  * Copyright (C) 2002 Richard Hult <richard@imendio.com>
  * Copyright (C) 2002 Mikael Hallendal <micke@imendio.com>
@@ -26,11 +26,11 @@
 #include <string.h>
 #include <popt.h>
 #include <gtk/gtkwidget.h>
-#include <libgnome/gnome-i18n.h>
+#include <gtk/gtkmain.h>
+#include <glib/gi18n.h>
 #include <libgnome/gnome-program.h>
 #include <libgnomeui/gnome-ui-init.h>
 #include <libgnomeui/gnome-window-icon.h>
-#include <libbonoboui.h>
 #include "planner-application.h"
 #include "planner-window.h"
 
@@ -44,7 +44,8 @@ main (int argc, char **argv)
         GnomeProgram       *program;
 	gchar              *geometry;
 	poptContext         popt_context;
-	const char        **args;
+	const gchar       **args;
+	gint                i;
 	struct poptOption   options[] = {
 		{ "geometry", 'g', POPT_ARG_STRING, &geometry, 0,
 		  N_("Create the initial window with the given geometry."), N_("GEOMETRY") },
@@ -74,22 +75,16 @@ main (int argc, char **argv)
 	args = poptGetArgs (popt_context);
 	if (geometry != NULL && args != NULL && args[0] != NULL && args[1] != NULL) {
 		g_warning (_("planner: --geometry cannot be used with more than one file."));
-		exit (1);
+		return (1);
 	}
 
 	if (g_getenv ("MRP_G_FATAL_WARNINGS") != NULL) {
 		g_log_set_always_fatal (G_LOG_LEVEL_MASK);
 	}
-
+	
 	application = planner_application_new ();
 
 	main_window = planner_application_new_window (application);
-
-	if (main_window) {
-		gnome_window_icon_set_default_from_file (
-			DATADIR "/pixmaps/gnome-planner.png");
-	}
-
 	if (geometry != NULL) {
 		gtk_window_parse_geometry (GTK_WINDOW (main_window), geometry);
 	}
@@ -97,10 +92,27 @@ main (int argc, char **argv)
 	gtk_widget_show_all (main_window);
 
 	if (args != NULL) {
-		planner_window_open (PLANNER_WINDOW (main_window), args[0]);
+		i = 0;
+		while (args[i]) {
+			if (g_str_has_prefix (args[i], "file:")) {
+				planner_window_open_in_existing_or_new (
+					PLANNER_WINDOW (main_window), args[i], FALSE);
+			} else {
+				gchar *uri;
+
+				uri = g_filename_to_uri (args[i], NULL, NULL);
+				if (uri) {
+					planner_window_open_in_existing_or_new (
+						PLANNER_WINDOW (main_window), uri, FALSE);
+					g_free (uri);
+				}
+			}
+				
+			i++;
+		}
 	}
 
-        bonobo_ui_main ();
+        gtk_main ();
 
 	g_object_unref (application);
 	
