@@ -24,7 +24,7 @@
 
 #include <math.h>
 #include <gtk/gtk.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include "planner-sidebar.h"
 
 struct _PlannerSidebarPriv {
