@@ -25,7 +25,7 @@
 #include <string.h>
 #include <gtk/gtk.h>
 #include <libplanner/planner.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnomeprint/gnome-print.h>
 #include "planner-print-job.h"
 #include "planner-table-print-sheet.h"
@@ -172,7 +172,6 @@ table_print_sheet_print_cell (PlannerTablePrintSheet *sheet,
 		      "weight", &weight,
 		      NULL);
 
-
 	if (!str) {
 		return;
 	}
@@ -207,15 +206,17 @@ table_print_sheet_print_page (PlannerTablePrintSheet *sheet, PrintPage *page)
 						      PRINT_COL (c->data),
 						      PRINT_ROW (r->data),
 						      x, y);
-			x += PRINT_COL(c->data)->width;
+			x += PRINT_COL (c->data)->width;
 			planner_print_job_moveto (sheet->job, 
 					     x, y); 
 			planner_print_job_lineto (sheet->job, 
 					     x,
-					     y + PRINT_ROW(r->data)->height);
+					     y + PRINT_ROW (r->data)->height);
 			gnome_print_stroke (sheet->job->pc);
 		}
-		y += PRINT_ROW(r->data)->height;
+
+		
+		y += PRINT_ROW (r->data)->height;
 		planner_print_job_moveto (sheet->job, 0, y);
 		planner_print_job_lineto (sheet->job, x, y);
 		gnome_print_stroke (sheet->job->pc);
@@ -296,14 +297,15 @@ table_print_sheet_foreach_row (GtkTreeModel *model,
 			g_object_get (cell,
 				      "text", &str,
 				      NULL);
-			
+
  			if (column->expander_column) {
 				extra += depth * INDENT_FACTOR * sheet->x_pad;
  			}
+
 			
 			column->width = MAX (column->width, 
-					     (str ? gnome_font_get_width_utf8 (sheet->font, str) : 0) + extra);
-			
+					     (str ? gnome_font_get_width_utf8 (sheet->font, str) : 0)
+					     + extra);
 /* 		d(g_print ("New width: %f\n", column->width)); */
 			
 			g_free (str);
@@ -380,9 +382,9 @@ table_print_sheet_create_pages (PlannerTablePrintSheet *sheet)
 
 static GSList *
 table_print_sheet_add_row_of_pages (PlannerTablePrintSheet *sheet,
-				    GSList            *page_row,
-				    GSList            *rows,
-				    gboolean           new_row)
+				    GSList                 *page_row,
+				    GSList                 *rows,
+				    gboolean                new_row)
 {
 	GSList  *l;
 	GSList  *added_rows = NULL;
